@@ -4,6 +4,9 @@ from botocore.exceptions import ClientError
 import traceback
 from boto3.dynamodb.conditions import Key
 import time
+from properly_util_python.dynamo_data_utils import DynamoData
+
+from properly_util_python.schemas import UserSchema
 
 
 logger = logging.getLogger()
@@ -13,7 +16,7 @@ logger.setLevel(logging.INFO)
 class UserAuthHelper:
 
     OPERATIONS_ROLE_ID = "S4jlPBglYkqccBcWody6hw"
-    OWNER_ROLE_ID = "jczqf4GgkEKd1bxtTgpJOg"
+    BASIC_ROLE_ID = "jczqf4GgkEKd1bxtTgpJOg"
 
     def __init__(self, dynamo_helper):
         self.dynamo_helper = dynamo_helper
@@ -227,10 +230,34 @@ class UserAuthHelper:
         # this is not implemented yet, just using global role check until this capability is required
         raise NotImplementedError("roles for a resource is not implemented")
 
-    def is_user_in_role(self, properly_user_id, role_id):
+    #accepts None or empty user_id and role_id
+    def is_user_in_role(self, properly_user_id: str, role_id: str):
+
+        if (not isinstance(properly_user_id, str) or (properly_user_id == "" ) ):
+            return False #None or empty users are in no role
+
+
+        user_table = self.table_helper.get_table(TableHelper.USER_TABLE_NAME)
+
+        response = user_table.get_item(Key={UserSchema.ID: properly_user_id},) #Consider: ConsistentRead=True
+
+        user_dict_dynamo = response.get('Item')
+        if (user_dict_dynamo is None):
+            return False  # not in a role if the user doesn't exist
+
+        if (role_id == UserAuthHelper.BASIC_ROLE_ID):
+            return True  # if the user exists they are automatically in the basic role
+
+        user_dict = DynamoData.to_dict(user_dict_dynamo)
+
+        roles_array = user_dict.get(UserSchema.ROLES)
+
+        if (roles_array is None):
+            return False
+
+        has_role_flag = role_id in roles_array
+
+        return has_role_flag
 
-        # find user by properly_user_id
-        # check roles array for the requested role_id
 
-        return True
 
